#!/bin/bash

# This script is meant to help you take a Yellow Dog Linux 6.2 installation and quickly install
# everything zerogame requires to be up and running. This script is in constant flux and is not
# meant to be used in a stable environment yet.

# Version 0.50
# By Jason Carter (jay@zerojay.com)


clear

# User introduction to Zerogame.

echo "Zerogame Installer v0.50" 
echo "By zerojay (jay@zerojay.com)"
echo -e '\n'
echo "Introduction to Zerogame"
echo "Welcome to Zerogame, a script that makes converting your Yellow Dog Linux 6.1/6.2 install into an emulation heaven quick and simple."
echo "First, the installer will make some basic repository changes that are required before installation. Afterwards, you will be able to configure which emulators will be installed, automatic button configuration and more."
echo -e '\n'
read -p "Press the Enter key when you are ready to proceed with installation."

# Step 1: Install the PS3 Bodega repository (eternal thanks to billb).

echo "Installing PS3 Bodega repository..."
# Step 2: Install PS3 Bodega repo.
cp ./configs/yum/ps3bodega.repo /etc/yum.repos.d/ps3bodega.repo
echo "Installing PS3 Bodega repository... done."

# Step 2: Force yum to clean its cache so that the PS3 Bodega repo will figure into installation.

echo "Cleaning the Yum repository..."
yum -y clean all
echo "Cleaning the Yum repository... done."

# Step 3: Protect Yellowdog repos from updates.

echo "Protecting the Yellow Dog Linux Base and Updates repositories..."

cp ./configs/yum/yellowdog-base.repo /etc/yum.repos.d/yellowdog-base.repo
cp ./configs/yum/yellowdog-updates.repo /etc/yum.repos.d/yellowdog-updates.repo
echo "Protecting the Yellow Dog Linux Base and Updates repositories... done."
echo -e '\n'

clear

useradd zerogame
passwd -d zerogame

# User introduction to Bluetooth pairing.

echo "Bluetooth Pairing Information"
echo "For pairing Sixaxis or DualShock controllers, after dismissing this message and selecting yes to the following question, please wait until you see the notification that the Bluetooth HID daemon has started before pressing the Playstation button on your controllers. The controllers are successfully paired when a notification for each controller shows up on the screen."
echo "Pairing mode will last 30 seconds, after which installation will continue."
echo "Note: Only two controllers can be used wirelessly at the same time. You can, however, plug in two more controllers through USB if you wish."

# Step 4: Pairing Bluetooth controllers.

while true; do
    read -n1 -p "Do you wish to use a SixAxis/DualShock 3 controller wirelessly through Bluetooth? [y/n] " blueans
    echo -e '\n'
    case $blueans in
	[Yy]* )
	  echo -e '\n'

	  # Ask user if they would like to use Bluetooth.
	  # If not, disable Bluetooth services too.
	  # If so, stop the hidd daemon and start it manually.
	  # Ask user to pair controllers.
	 
	  echo "Pairing SixAxis/DualShock 3 controllers via Bluetooth... turn on your controllers with the Playstation button when the HID daemon message shows up below."
	  
	  service hidd stop
	  sleep 2
	  hidd --server --nocheck -n &
	  sleep 30
	  killall hidd
	  echo "Pairing SixAxis/DualShock 3 controllers via Bluetooth... done."
	  
	  chkconfig --level 2345 bluetooth on
	  chkconfig --level 2345 hidd on
	  echo "Reenabling the Bluetooth HID daemon..."
	  
	  service hidd start
	  echo "Reenabling the Bluetooth HID daemon... done."
	  break;;
	[Nn]* )
	  echo "Disabling unneccessary system services... hidd..."
	  
	  chkconfig --level 2345 hidd off
	  echo "Disabling unneccessary system services... hidd... done."
	  echo "Disabling unneccessary system services... bluetooth..."
	  
	  chkconfig --level 2345 bluetooth off
	  echo "Disabling unneccessary system services... bluetooth... done."
          break;;
        * ) 
          echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

# Step 5: Disable useless/annoying servers on both runlevel 3 and 5.

echo "Disabling unneccessary system services..."
echo "Errors seen in this section are non-fatal and nothing to worry about."

chkconfig --level 2345 atd off
chkconfig --level 2345 avahi-daemon off
chkconfig --level 2345 anacron off 
chkconfig --level 2345 cpuspeed off 
chkconfig --level 2345 cups off 
chkconfig --level 2345 hplip off 
chkconfig --level 2345 ip6tables off 
chkconfig --level 2345 iptables off  
chkconfig --level 2345 isdn off 
chkconfig --level 2345 mdmonitor off
chkconfig --level 2345 nfslock off
chkconfig --level 2345 pcscd off 
chkconfig --level 2345 restorecond off 
chkconfig --level 2345 gpm off 
chkconfig --level 2345 rpcgssd off 
chkconfig --level 2345 rpcidmapd off 
chkconfig --level 2345 sendmail off 
chkconfig --level 2345 yum-updatesd off
chkconfig --level 2345 auditd off 

# Step 6: Download and set up proper alsa.cards.
# Possibly unneeded now?

#echo "Installing ALSA sound configuration for PlayStation 3 Linux..."

#cp ./configs/alsa/PS3.conf /etc/alsa/cards/PS3.conf
#mkdir /usr/share/alsa/cards/
#cp ./configs/alsa/PS3.conf /usr/share/alsa/cards/PS3.conf
#echo "Installing ALSA sound configuration for PlayStation 3 Linux... done."

# Step 7: Set up Windows File Sharing. If not, create directories on PS hard drive.

mkdir /home/zerogame/gamefiles/
chown zerogame:zerogame /home/zerogame/gamefiles/

while true; do
    read -n1 -p "Would you like to setup Windows File Sharing/SAMBA for loading your ROMs/previews over your LAN? [y/n] " laninstall
    echo -e '\n'
    case $laninstall in
	[Yy]* )
	  read -p "What is the name or IP address of the computer your ROMs are stored upon? " ipname
	  echo -e '\n'
	  read -p "What is the name of the Windows File Share/SAMBA share? " sharename
	  echo -e '\n'
          read -p "What is the workgroup/domain for $ipname? " domainname
	  echo -e '\n'
          read -p "What is a valid username for the Windows File Share/SAMBA share? " shareusername
          echo -e '\n'
          read -p "What is the password for $shareusername? " sharepassword
	  echo -e '\n'
	  while true; do
	      echo "Is your share on a Linux computer that requires unix extensions turned off?"
              read -n1 -p "If you aren't sure, say N. [y/n] " unixext
              echo -e '\n'
	      case $unixext in
		  [Yy]* )
		    echo "mount.cifs //$ipname/$sharename/ /home/zerogame/gamefiles/ -o user=$shareusername,pass=$sharepassword,domain=$domainname,nounix" >> /etc/rc.local
		    break;;
		  [Nn]* )
		    echo "mount.cifs //$ipname/$sharename/ /home/zerogame/gamefiles/ -o user=$shareusername,pass=$sharepassword,domain=$domainname" >> /etc/rc.local
		    break;;
		  * ) echo -e "\nPlease answer yes or no.";;
	      esac
	  done
	  break;;
	[Nn]* )
          mkdir -p /home/zerogame/gamefiles/roms/
          mkdir -p /home/zerogame/gamefiles/music/
          mkdir -p /home/zerogame/gamefiles/previews/artwork1/
		  mkdir -p /home/zerogame/gamefiles/previews/artwork2/
          mkdir -p /home/zerogame/gamefiles/previews/videos/
	  break;;
	* ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

# Step 9: Ask user for platforms he/she would like to emulate from a dialog menubox.
# Install emulators for those systems.


while true; do
    read -n1 -p "Would you like to install arcade game (MAME) support? [y/n] " mameinstall
    case $mameinstall in
	[Yy]* )
          yumlist="$yumlist sdlmame sdlmame-tools"
          mameinstall="1"
          if [ ! "$ipname" ]; then
          	mkdir /home/zerogame/gamefiles/roms/mame/
          	mkdir /home/zerogame/gamefiles/previews/artwork1/mame/
			mkdir /home/zerogame/gamefiles/previews/artwork2/mame/
          	mkdir /home/zerogame/gamefiles/previews/videos/mame/
          fi
          break;;
        [Nn]* )
          mameinstall="0"
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Atari Lynx support (requires Lynx BIOS file)? [y/n] " lynxinstall
    case $lynxinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  lynxinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/lynx/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/lynx/
		mkdir /home/zerogame/gamefiles/previews/artwork2/lynx/
	    mkdir /home/zerogame/gamefiles/previews/videos/lynx/
        fi
        break;;
      [Nn]* )
        lynxinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Bandai Wonderswan support? [y/n] " wsinstall
    case $wsinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  wsinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/ws/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/ws/
		mkdir /home/zerogame/gamefiles/previews/artwork2/ws/
	    mkdir /home/zerogame/gamefiles/previews/videos/ws/
        fi
        break;;
      [Nn]* )
        wsinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Bandai Wonderswan Color support? [y/n] " wscinstall
    case $wscinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  wscinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/wsc/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/wsc/
		mkdir /home/zerogame/gamefiles/previews/artwork1/wsc/
	    mkdir /home/zerogame/gamefiles/previews/videos/wsc/
        fi
        break;;
      [Nn]* )
        wscinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

# while true; do
#     read -n1 -p "Would you like to install Commodore 64 support? [y/n] " c64install
#     case $c64install in
# 	[Yy]* )
#       yumlist="$yumlist vice"
# 	  c64install="1"
# 	  if [ ! "$ipname" ]; then
# 	    mkdir /home/zerogame/gamefiles/roms/c64/
# 	    mkdir /home/zerogame/gamefiles/previews/artwork1/c64/
#           mkdir /home/zerogame/gamefiles/previews/artwork2/c64/
# 	    mkdir /home/zerogame/gamefiles/previews/videos/c64/
#       fi
#       break;;
#     [Nn]* )
#       c64install="0"
#       break;;
#      * ) echo -e "\nPlease answer yes or no.";;
#     esac
# done
# echo -e '\n'

while true; do
    read -n1 -p "Would you like to install NEC Turbografx-16 support? [y/n] " tg16install
    case $tg16install in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  tg16install="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/tg16/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/tg16/
		mkdir /home/zerogame/gamefiles/previews/artwork2/tg16/
	    mkdir /home/zerogame/gamefiles/previews/videos/tg16/
	  fi
        break;;
      [Nn]* )
        tg16install="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Neo Geo Pocket support? [y/n] " ngpinstall
    case $ngpinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  ngpinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/ngp/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/ngp/
		mkdir /home/zerogame/gamefiles/previews/artwork2/ngp/
	    mkdir /home/zerogame/gamefiles/previews/videos/ngp/
        fi
        break;;
      [Nn]* )
        ngpinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Neo Geo Pocket Color support? [y/n] " ngpcinstall
    case $ngpcinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  ngpcinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/ngpc/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/ngpc/
		mkdir /home/zerogame/gamefiles/previews/artwork2/ngpc/
	    mkdir /home/zerogame/gamefiles/previews/videos/ngpc/
        fi
        break;;
      [Nn]* )
        ngpcinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Entertainment System support? [y/n] " nesinstall
    case $nesinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  nesinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/nes/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/nes/
		mkdir /home/zerogame/gamefiles/previews/artwork2/nes/
	    mkdir /home/zerogame/gamefiles/previews/videos/nes/
        fi
        break;;
      [Nn]* )
        nesinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Famicom Disk System support (requires FDS BIOS)? [y/n] " fdsinstall
    case $fdsinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  fdsinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/fds/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/fds/
		mkdir /home/zerogame/gamefiles/previews/artwork2/fds/
	    mkdir /home/zerogame/gamefiles/previews/videos/fds/
        fi
        break;;
      [Nn]* )
        fdsinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Gameboy support? [y/n] " gbinstall
    case $gbinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  gbinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gb/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gb/
		mkdir /home/zerogame/gamefiles/previews/artwork2/gb/
	    mkdir /home/zerogame/gamefiles/previews/videos/gb/
        fi
        break;;
      [Nn]* )
        gbinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Gameboy Advance support? [y/n] " gbainstall
    case $gbainstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  gbainstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gba/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gba/
		mkdir /home/zerogame/gamefiles/previews/artwork2/gba/
	    mkdir /home/zerogame/gamefiles/previews/videos/gba/
        fi
        break;;
      [Nn]* )
        gbainstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Gameboy Color support? [y/n] " gbcinstall
    case $gbcinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  gbcinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gbc/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gbc/
		mkdir /home/zerogame/gamefiles/previews/artwork2/gbc/
	    mkdir /home/zerogame/gamefiles/previews/videos/gbc/
        fi
        break;;
      [Nn]* )
        gbcinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Nintendo Super NES support? [y/n] " snesinstall
    case $snesinstall in
	[Yy]* )
	snesinstall="1"
	if [ ! "$ipname" ]; then
	  mkdir /home/zerogame/gamefiles/roms/snes/
	  mkdir /home/zerogame/gamefiles/previews/artwork1/snes/
	  mkdir /home/zerogame/gamefiles/previews/artwork2/snes/
	  mkdir /home/zerogame/gamefiles/previews/videos/snes/
        fi
        break;;
      [Nn]* )
        snesinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega Genesis/MegaDrive support? [y/n] " geninstall
    case $geninstall in
	[Yy]* )
        geninstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gen/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gen/
		mkdir /home/zerogame/gamefiles/previews/artwork2/gen/
	    mkdir /home/zerogame/gamefiles/previews/videos/gen/
	  fi
        break;;
      [Nn]* )
        geninstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega CD support (requires SegaCD BIOS)? [y/n] " segacdinstall
    case $segacdinstall in
	[Yy]* )
        segacdinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/segacd/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/segacd/
		mkdir /home/zerogame/gamefiles/previews/artwork2/segacd/
	    mkdir /home/zerogame/gamefiles/previews/videos/segacd/
	  fi
        break;;
      [Nn]* )
        segacdinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega Game Gear support? [y/n] " gginstall
    case $gginstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  gginstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/gg/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/gg/
		mkdir /home/zerogame/gamefiles/previews/artwork2/gg/
	    mkdir /home/zerogame/gamefiles/previews/videos/gg/
        fi
        break;;
      [Nn]* )
        gginstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

while true; do
    read -n1 -p "Would you like to install Sega Master System support? [y/n] " smsinstall
    case $smsinstall in
	[Yy]* )
        yumlist="$yumlist mednafen"
	  smsinstall="1"
	  if [ ! "$ipname" ]; then
	    mkdir /home/zerogame/gamefiles/roms/sms/
	    mkdir /home/zerogame/gamefiles/previews/artwork1/sms/
		mkdir /home/zerogame/gamefiles/previews/artwork2/sms/
	    mkdir /home/zerogame/gamefiles/previews/videos/sms/
        fi
        break;;
      [Nn]* )
        smsinstall="0"
        break;;
      * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

#while true; do
#    read -n1 -p "Would you like to install TV Show support? [y/n] " tvinstall
#    case $tvinstall in
#	[Yy]* )
#          yumlist="$yumlist vlc"
#	   tvinstall="1"
#	    if [ ! "$ipname" ]; then
#	     mkdir /home/zerogame/gamefiles/previews/artwork1/tv/
#            mkdir /home/zerogame/gamefiles/previews/artwork2/tv/
#            mkdir /home/zerogame/gamefiles/previews/videos/tv/
#          fi
#          break;;
#        [Nn]* )
#          tvinstall="0"
#          break;;
#        * ) echo -e "\nPlease answer yes or no.";;
#    esac
#done
#echo -e '\n'

#while true; do
#    read -n1 -p "Would you like to install Movies support? [y/n] " moviesinstall
#    case $moviesinstall in
#	[Yy]* )
#          yumlist="$yumlist vlc"
#          moviesinstall="1"
#	    if [ ! "$ipname" ]; then
#             mkdir /home/zerogame/gamefiles/previews/artwork1/movies/
#             mkdir /home/zerogame/gamefiles/previews/artwork2/movies/
#             mkdir /home/zerogame/gamefiles/previews/videos/movies/
#          fi
#          break;;
#        [Nn]* )
#          moviesinstall="0"
#          break;;
#        * ) echo -e "\nPlease answer yes or no.";;
#    esac
#done
#echo -e '\n'

# Default installation list.
yumlist="$yumlist fscaler pygame xorg-x11-utils gstreamer-plugins-good gstreamer-plugins-bad gstreamer-plugins-ugly gstreamer-python fluxbox boost bluez-hcidump "


echo "Installing console emulators, tools and dependencies. This may take a few minutes..."

# Much faster to install all in one shot as billb mentioned.

yum -y install $yumlist

# Installing XE seperately as billb hasn't added 2.16.2 official to PS3Bodega repo, so we'll use this one which supports autofill for the moment.
if [ "$geninstall" == "1" ]; then
 yum -y --nogpgcheck localinstall /root/packages/xe-2.16.1-2.ydl6.bdg.ppc.rpm
fi

# If XE has already been installed because the user selected Genesis support, don't bother wasting time/bandwidth redownloading/reinstalling for SegaCD as well.
if [ "$segacdinstall" == "1" ]; then
 if [ "$geninstall" == "0" ]; then
    yum -y --nogpgcheck localinstall /root/packages/xe-2.16.1-2.ydl6.bdg.ppc.rpm
 fi
fi

if [ "$snesinstall" == "1" ]; then
 yum -y --nogpgcheck localinstall /root/packages/snes9x-gtk-1.51-67.ydl6.bdg.ppc.rpm
fi

echo "Installing console emulators, tools and dependencies... done."

# Step 10: Install Wahcade music.
# Mirror these on my website, give credit.

 cd /root/packages/
 tar zxvf wahcade-0.99pre8.tar.gz
 cd /root/packages/wahcade/
 echo "Installing Wahcade..."
 
 ./install
 echo "Installing Wahcade... done."
 cd /root/patches/
 
 # Patch constants.py to allow alternative sound sources such as .MOD files.
 cp constants.py /usr/local/share/wahcade/

 # Patch filters.py to remove restriction on MAME previews.
 cp filters.py /usr/local/share/wahcade/
 cd /root/packages/
 tar zxvf gizmo-install.tar.gz -C /
 cp /root/configs/gizmod/000-CatchZerogame.py /etc/gizmod/modules.d/
 cp /root/configs/gizmod/GizmoDeviceStrings.py /etc/gizmod/
 cp -R /root/sfx/ /home/zerogame/
 chown -R zerogame:zerogame /home/zerogame/sfx/ 
 
 echo "Installing configuration files..."
 
 cd /root/

 mkdir /home/zerogame/.fluxbox/
 cp -R ./configs/fluxbox/* /home/zerogame/.fluxbox/
 chown -R zerogame:zerogame /home/zerogame/.fluxbox/
 
 mkdir -p /home/zerogame/.wahcade/
 mkdir -p /home/zerogame/.wahcade/ini/
 mkdir -p /home/zerogame/.wahcade/files/
 mkdir -p /home/zerogame/.wahcade/layouts/
 #mkdir -p /home/zerogame/.wahcade/layouts/zerogame-1080p/
 #mkdir -p /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-1080p/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 #mkdir -p /home/zerogame/.wahcade/layouts/zerogame-720p/
 #mkdir -p /home/zerogame/.wahcade/layouts/zerogame-720pb/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-720p/
 mkdir -p /home/zerogame/.wahcade/layouts/retrogame-720pb/
 mkdir -p /home/zerogame/.wahcade/ctrlr/ 

 cp ./configs/wahcade/ctrlr/* /home/zerogame/.wahcade/ctrlr/
 cp ./configs/wahcade/cpviewer.ini /home/zerogame/.wahcade/
 cp ./configs/wahcade/histview.ini /home/zerogame/.wahcade/
 cp ./configs/wahcade/wahcade.ini /home/zerogame/.wahcade/ 

 
 if [ "$geninstall" -eq 1 ]; then 
  cp -R ./configs/xe-nocd/ /home/zerogame/.xe/
  cp -R ./configs/xe-nocd/ /home/zerogame/.zerogame/
  chown -R zerogame:zerogame /home/zerogame/.xe/
  chown -R zerogame:zerogame /home/zerogame/.zerogame/
  cp ./configs/wahcade/ini/gen.ini /home/zerogame/.wahcade/ini/gen.ini
  cp ./configs/wahcade/ini/gen-0.ini /home/zerogame/.wahcade/ini/gen-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pgen.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbgen.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pgen.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbgen.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pgen.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgen.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgen.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgen.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/gen.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/gen.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/gen.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/gen.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/gen.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gen.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/gen.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gen.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$nesinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/nes.ini /home/zerogame/.wahcade/ini/nes.ini
  cp ./configs/wahcade/ini/nes-0.ini /home/zerogame/.wahcade/ini/nes-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pnes.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbnes.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pnes.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbnes.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pnes.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbnes.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pnes.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbnes.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/nes.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/nes.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/nes.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/nes.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/nes.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/nes.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/nes.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/nes.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$gbinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gb.ini /home/zerogame/.wahcade/ini/gb.ini
  cp ./configs/wahcade/ini/gb-0.ini /home/zerogame/.wahcade/ini/gb-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pgb.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbgb.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pgb.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbgb.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pgb.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgb.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgb.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgb.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/gb.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/gb.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/gb.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/gb.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/gb.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gb.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/gb.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gb.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$lynxinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/lynx.ini /home/zerogame/.wahcade/ini/lynx.ini
  cp ./configs/wahcade/ini/lynx-0.ini /home/zerogame/.wahcade/ini/lynx-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080plynx.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pblynx.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720plynx.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pblynx.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080plynx.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pblynx.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720plynx.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pblynx.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/lynx.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/lynx.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/lynx.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/lynx.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/lynx.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$gbcinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gbc.ini /home/zerogame/.wahcade/ini/gbc.ini
  cp ./configs/wahcade/ini/gbc-0.ini /home/zerogame/.wahcade/ini/gbc-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pgbc.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbgbc.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pgbc.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbgbc.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pgbc.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgbc.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgbc.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgbc.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/gbc.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/gbc.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/gbc.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/gbc.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gbc.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$gbainstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gba.ini /home/zerogame/.wahcade/ini/gba.ini
  cp ./configs/wahcade/ini/gba-0.ini /home/zerogame/.wahcade/ini/gba-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pgba.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbgba.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pgba.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbgba.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pgba.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgba.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgba.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgba.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/gba.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/gba.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/gba.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/gba.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/gba.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gba.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/gba.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gba.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$wsinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/ws.ini /home/zerogame/.wahcade/ini/ws.ini
  cp ./configs/wahcade/ini/ws-0.ini /home/zerogame/.wahcade/ini/ws-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pws.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbws.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pws.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbws.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pws.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbws.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pws.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbws.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/ws.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/ws.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/ws.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/ws.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/ws.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/ws.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/ws.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/ws.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$smsinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/sms.ini /home/zerogame/.wahcade/ini/sms.ini
  cp ./configs/wahcade/ini/sms-0.ini /home/zerogame/.wahcade/ini/sms-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080psms.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbsms.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720psms.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbsms.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080psms.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbsms.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720psms.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbsms.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/sms.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/sms.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/sms.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/sms.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/sms.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/sms.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/sms.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/sms.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$gginstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/gg.ini /home/zerogame/.wahcade/ini/gg.ini
  cp ./configs/wahcade/ini/gg-0.ini /home/zerogame/.wahcade/ini/gg-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pgg.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbgg.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pgg.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbgg.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pgg.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbgg.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pgg.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbgg.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/gg.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/gg.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/gg.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/gg.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/gg.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/gg.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/gg.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/gg.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$snesinstall" -eq 1 ]; then
  cp -R ./configs/snes9x/ /home/zerogame/.snes9x/
  chown -R zerogame:zerogame /home/zerogame/.snes9x/
  cp ./configs/wahcade/ini/snes.ini /home/zerogame/.wahcade/ini/snes.ini
  cp ./configs/wahcade/ini/snes-0.ini /home/zerogame/.wahcade/ini/snes-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080psnes.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbsnes.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720psnes.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbsnes.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080psnes.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbsnes.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720psnes.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbsnes.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/snes.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/snes.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/snes.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/snes.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/snes.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/snes.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/snes.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/snes.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 #if [ "$c64install" -eq 1 ]; then
 # cp -R ./configs/vice/ /home/zerogame/.vice/
 # chown -R zerogame:zerogame /home/zerogame/.vice/
 # cp ./configs/wahcade/ini/c64.ini /home/zerogame/.wahcade/ini/c64.ini
 # cp ./configs/wahcade/ini/c64-0.ini /home/zerogame/.wahcade/ini/c64-0.ini
 # cp ./backgrounds/zerogame-1080p/zerogame1080pc64.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
 # cp ./backgrounds/zerogame-1080pb/zerogame1080pbc64.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 # cp ./backgrounds/zerogame-720p/zerogame720pc64.png /home/zerogame/.wahcade/layouts/zerogame-720p/
 # cp ./backgrounds/zerogame-720pb/zerogame720pbc64.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
 # cp ./backgrounds/retrogame-1080p/retrogame1080pc64.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 # cp ./backgrounds/retrogame-1080pb/retrogame1080pbc64.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 # cp ./backgrounds/retrogame-720p/retrogame720pc64.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 # cp ./backgrounds/retrogame-720pb/retrogame720pbc64.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 # cp ./layouts/zerogame-1080p/c64.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
 # cp ./layouts/zerogame-1080pb/c64.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 # cp ./layouts/zerogame-720p/c64.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
 # cp ./layouts/zerogame-720pb/c64.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
 # cp ./layouts/retrogame-1080p/c64.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
 # cp ./layouts/retrogame-1080pb/c64.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
 # cp ./layouts/retrogame-720p/c64.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
 # cp ./layouts/retrogame-720pb/c64.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 #fi

 if [ "$mameinstall" -eq 1 ]; then
  cp -R ./configs/mame/ /home/zerogame/.mame/
  chown -R zerogame:zerogame /home/zerogame/.mame/
  cp ./configs/wahcade/ini/mame.ini /home/zerogame/.wahcade/ini/mame.ini
  cp ./configs/wahcade/ini/mame-0.ini /home/zerogame/.wahcade/ini/mame-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pmame.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbmame.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pmame.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbmame.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pmame.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbmame.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pmame.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbmame.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/mame.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/mame.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/mame.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/mame.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/mame.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/mame.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/mame.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/mame.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$segacdinstall" -eq 1 ]; then 
  cp -R ./configs/xe/ /home/zerogame/.xe/
  cp -R ./configs/xe/ /home/zerogame/.zerogame/
  chown -R zerogame:zerogame /home/zerogame/.xe/
  chown -R zerogame:zerogame /home/zerogame/.zerogame/
  cp ./configs/wahcade/ini/segacd.ini /home/zerogame/.wahcade/ini/segacd.ini
  cp ./configs/wahcade/ini/segacd-0.ini /home/zerogame/.wahcade/ini/segacd-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080psegacd.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbsegacd.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720psegacd.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbsegacd.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080psegacd.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbsegacd.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720psegacd.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbsegacd.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/segacd.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/segacd.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/segacd.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/segacd.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/segacd.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$wscinstall" -eq 1 ]; then 
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.xe/
  cp ./configs/wahcade/ini/wsc.ini /home/zerogame/.wahcade/ini/wsc.ini
  cp ./configs/wahcade/ini/wsc-0.ini /home/zerogame/.wahcade/ini/wsc-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pwsc.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbwsc.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pwsc.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbwsc.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pwsc.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbwsc.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pwsc.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbwsc.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/wsc.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/wsc.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/wsc.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/wsc.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/wsc.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi

 if [ "$fdsinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/fds.ini /home/zerogame/.wahcade/ini/fds.ini
  cp ./configs/wahcade/ini/fds-0.ini /home/zerogame/.wahcade/ini/fds-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pfds.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbfds.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pfds.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbfds.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pfds.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbfds.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pfds.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbfds.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/fds.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/fds.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/fds.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/fds.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/fds.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/fds.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/fds.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/fds.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$ngpinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/ngp.ini /home/zerogame/.wahcade/ini/ngp.ini
  cp ./configs/wahcade/ini/ngp-0.ini /home/zerogame/.wahcade/ini/ngp-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pngp.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbngp.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pngp.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbngp.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pngp.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbngp.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pngp.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbngp.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/ngp.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/ngp.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/ngp.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/ngp.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/ngp.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$ngpcinstall" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/ngpc.ini /home/zerogame/.wahcade/ini/ngpc.ini
  cp ./configs/wahcade/ini/ngpc-0.ini /home/zerogame/.wahcade/ini/ngpc-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080pngpc.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbngpc.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720pngpc.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbngpc.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080pngpc.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbngpc.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720pngpc.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbngpc.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/ngpc.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/ngpc.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/ngpc.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/ngpc.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/ngpc.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
 if [ "$tg16install" -eq 1 ]; then
  cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
  chown -R zerogame:zerogame /home/zerogame/.mednafen/
  cp ./configs/wahcade/ini/tg16.ini /home/zerogame/.wahcade/ini/tg16.ini
  cp ./configs/wahcade/ini/tg16-0.ini /home/zerogame/.wahcade/ini/tg16-0.ini
  #cp ./backgrounds/zerogame-1080p/zerogame1080ptg16.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./backgrounds/zerogame-1080pb/zerogame1080pbtg16.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./backgrounds/zerogame-720p/zerogame720ptg16.png /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./backgrounds/zerogame-720pb/zerogame720pbtg16.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./backgrounds/retrogame-1080p/retrogame1080ptg16.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./backgrounds/retrogame-1080pb/retrogame1080pbtg16.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
  cp ./backgrounds/retrogame-720p/retrogame720ptg16.png /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./backgrounds/retrogame-720pb/retrogame720pbtg16.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
  #cp ./layouts/zerogame-1080p/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
  #cp ./layouts/zerogame-1080pb/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
  #cp ./layouts/zerogame-720p/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
  #cp ./layouts/zerogame-720pb/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
  cp ./layouts/retrogame-1080p/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-1080pb/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
  cp ./layouts/retrogame-720p/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
  cp ./layouts/retrogame-720pb/tg16.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 fi
 
#  if [ "$tvinstall" -eq 1 ]; then
#   cp -R ./configs/vlc/ /home/zerogame/.vlc/
#   chown -R zerogame:zerogame /home/zerogame/.vlc/
#   cp ./configs/wahcade/ini/tv.ini /home/zerogame/.wahcade/ini/tv.ini
#   cp ./configs/wahcade/ini/tv-0.ini /home/zerogame/.wahcade/ini/tv-0.ini
#   cp ./backgrounds/zerogame-1080p/zerogame1080ptv.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
#   cp ./backgrounds/zerogame-1080pb/zerogame1080pbtv.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
#   cp ./backgrounds/zerogame-720p/zerogame720ptv.png /home/zerogame/.wahcade/layouts/zerogame-720p/
#   cp ./backgrounds/zerogame-720pb/zerogame720pbtv.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
#   cp ./backgrounds/retrogame-1080p/retrogame1080ptv.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./backgrounds/retrogame-1080pb/retrogame1080pbtv.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./backgrounds/retrogame-720p/retrogame720ptv.png /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./backgrounds/retrogame-720pb/retrogame720pbtv.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
#   cp ./layouts/zerogame-1080p/tv.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
#   cp ./layouts/zerogame-1080pb/tv.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
#   cp ./layouts/zerogame-720p/tv.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
#   cp ./layouts/zerogame-720pb/tv.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
#   cp ./layouts/retrogame-1080p/tv.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-1080pb/tv.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-720p/tv.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./layouts/retrogame-720pb/tv.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
#  fi
#  
#  if [ "$moviesinstall" -eq 1 ]; then
#   cp -R ./configs/vlc/ /home/zerogame/.vlc/
#   chown -R zerogame:zerogame /home/zerogame/.vlc/
#   cp ./configs/wahcade/ini/movies.ini /home/zerogame/.wahcade/ini/movies.ini
#   cp ./configs/wahcade/ini/movies-0.ini /home/zerogame/.wahcade/ini/movies-0.ini
#   cp ./backgrounds/zerogame-1080p/zerogame1080pmovies.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
#   cp ./backgrounds/zerogame-1080pb/zerogame1080pbmovies.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
#   cp ./backgrounds/zerogame-720p/zerogame720pmovies.png /home/zerogame/.wahcade/layouts/zerogame-720p/
#   cp ./backgrounds/zerogame-720pb/zerogame720pbmovies.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
#   cp ./backgrounds/retrogame-1080p/retrogame1080pmovies.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./backgrounds/retrogame-1080pb/retrogame1080pbmovies.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./backgrounds/retrogame-720p/retrogame720pmovies.png /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./backgrounds/retrogame-720pb/retrogame720pbmovies.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
#   cp ./layouts/zerogame-1080p/movies.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
#   cp ./layouts/zerogame-1080pb/movies.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
#   cp ./layouts/zerogame-720p/movies.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
#   cp ./layouts/zerogame-720pb/movies.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
#   cp ./layouts/retrogame-1080p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-1080pb/movies.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-720p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./layouts/retrogame-720pb/movies.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
#  fi
 
 #if [ "$intellivisioninstall" -eq 1 ]; then
 # cp -R ./configs/mednafen/ /home/zerogame/.mednafen/
 # chown -R zerogame:zerogame /home/zerogame/.mednafen/
 # cp ./configs/wahcade/ini/nes.ini /home/zerogame/.wahcade/ini/nes.ini
 # cp ./configs/wahcade/ini/nes-0.ini /home/zerogame/.wahcade/ini/nes-0.ini
 # cp ./backgrounds/zerogame-1080p/zerogame1080pnes.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
 # cp ./backgrounds/zerogame-1080pb/zerogame1080pbnes.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 # cp ./backgrounds/zerogame-720p/zerogame720pnes.png /home/zerogame/.wahcade/layouts/zerogame-720p/
 # cp ./backgrounds/zerogame-720pb/zerogame720pbnes.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
#   cp ./backgrounds/retrogame-1080p/retrogame1080pmovies.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./backgrounds/retrogame-1080pb/retrogame1080pbmovies.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
#   cp ./backgrounds/retrogame-720p/retrogame720pmovies.png /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./backgrounds/retrogame-720pb/retrogame720pbmovies.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 # cp ./layouts/zerogame-1080p/nes.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
 # cp ./layouts/zerogame-1080pb/nes.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 # cp ./layouts/zerogame-720p/nes.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
 # cp ./layouts/zerogame-720pb/nes.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
#   cp ./layouts/retrogame-1080p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-1080pb/movies.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
#   cp ./layouts/retrogame-720p/movies.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
#   cp ./layouts/retrogame-720pb/movies.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/
 #fi

 cp ./configs/wahcade/ini/tools.ini /home/zerogame/.wahcade/ini/tools.ini
 cp ./configs/wahcade/ini/tools-0.ini /home/zerogame/.wahcade/ini/tools-0.ini
 cp ./configs/wahcade/files/tools-0.lst /home/zerogame/.wahcade/files/tools-0.lst
 chmod 444 /home/zerogame/.wahcade/files/tools-0.lst
 #cp ./backgrounds/zerogame-1080p/zerogame1080ptg16.png /home/zerogame/.wahcade/layouts/zerogame-1080p/
 #cp ./backgrounds/zerogame-1080pb/zerogame1080pbtg16.png /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 #cp ./backgrounds/zerogame-720p/zerogame720ptg16.png /home/zerogame/.wahcade/layouts/zerogame-720p/
 #cp ./backgrounds/zerogame-720pb/zerogame720pbtg16.png /home/zerogame/.wahcade/layouts/zerogame-720pb/
 cp ./backgrounds/retrogame-1080p/retrogame1080ptools.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./backgrounds/retrogame-1080pb/retrogame1080pbtools.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./backgrounds/retrogame-720p/retrogame720ptools.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./backgrounds/retrogame-720pb/retrogame720pbtools.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 #cp ./layouts/zerogame-1080p/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-1080p/
 #cp ./layouts/zerogame-1080pb/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-1080pb/
 #cp ./layouts/zerogame-720p/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-720p/
 #cp ./layouts/zerogame-720pb/tg16.lay /home/zerogame/.wahcade/layouts/zerogame-720pb/
 cp ./layouts/retrogame-1080p/tools.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./layouts/retrogame-1080pb/tools.lay /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./layouts/retrogame-720p/tools.lay /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./layouts/retrogame-720pb/tools.lay /home/zerogame/.wahcade/layouts/retrogame-720pb/

 cp ./configs/udev/50-udev.rules /etc/udev/rules.d/50-udev.rules 
 echo "input:x:600:zerogame" >> /etc/group
 cp -R ./configs/x/dmrc /home/zerogame/.dmrc
 chown zerogame:zerogame /home/zerogame/.dmrc
 chmod 644 /home/zerogame/.dmrc

 echo "Installing configuration files... done."
 
 echo "Installing scaler scripts..."
 
 mkdir /home/zerogame/.zerogame/tools/
 cp ./tools/* /home/zerogame/.zerogame/tools/

 chmod 755 /home/zerogame/.zerogame/tools/*.sh
 chown -R zerogame:zerogame /home/zerogame/.wahcade/
 cp ./backgrounds/retrogame-1080p/retrogame1080plaunch.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./backgrounds/retrogame-1080pb/retrogame1080pblaunch.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./backgrounds/retrogame-720p/retrogame720plaunch.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./backgrounds/retrogame-720pb/retrogame720pblaunch.png /home/zerogame/.wahcade/layouts/retrogame-720pb/
 cp ./backgrounds/retrogame-1080p/retrogame1080poptions.png /home/zerogame/.wahcade/layouts/retrogame-1080p/
 cp ./backgrounds/retrogame-1080pb/retrogame1080pboptions.png /home/zerogame/.wahcade/layouts/retrogame-1080pb/
 cp ./backgrounds/retrogame-720p/retrogame720poptions.png /home/zerogame/.wahcade/layouts/retrogame-720p/
 cp ./backgrounds/retrogame-720pb/retrogame720pboptions.png /home/zerogame/.wahcade/layouts/retrogame-720pb/

 echo "Installing scaler scripts... done."
 echo "Creating default mameinfo.xml file required by wahcade... this can take a while."
 
 mame -listxml > /home/zerogame/.wahcade/files/mameinfo.xml
 chown zerogame:zerogame /home/zerogame/.wahcade/files/mameinfo.xml
 echo "Creating default mameinfo.xml done."
 


while true; do
    read -n1 -p "Do you wish to download the free Arcade Ambience mp3s, about 350MB total, for use as Wahcade background music? [y/n] " mp3ans
    echo -e '\n'
    case $mp3ans in
	[Yy]* )
	    echo "Downloading Arcade Ambience mp3s: arcade.mp3 - 80MB (1/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade.mp3
	    
	    echo "Downloading Arcade Ambience mp3s: arcade.mp3 - 80MB (1/4)... done."
	    echo "Downloading Arcade Ambience mp3s: arcade83.mp3 - 90MB (2/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade83.mp3
	    echo "Downloading Arcade Ambience mp3s: arcade83.mp3 - 90MB (2/4)... done."
	    echo "Downloading Arcade Ambience mp3s: arcade92.mp3 - 92MB (3/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade92.mp3
	    echo "Downloading Arcade Ambience mp3s: arcade92.mp3 - 92MB (3/4)... done."
	    echo "Downloading Arcade Ambience mp3s: arcade86.mp3 - 92MB (4/4)..."
	    
	    wget -P /home/zerogame/music/ http://www.zerojay.com/zerogame/arcade86.mp3
	    echo "Downloading Arcade Ambience mp3s: arcade86.mp3 - 92MB (4/4)... done."
	    
            break;;
	[Nn]* )
	    echo "You can place your own music into /home/zerogame/music/."
            break;;
	* ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

#chown -R zerogame:zerogame /home/zerogame/gamefiles/music/
#chown -R zerogame:zerogame /home/zerogame/


# read -p "Do you want Zerogame to automatically log the games you play to a text file? [y/n] " logans
# echo -e '\n'
# if [ "$logans" == "n" ]; then
#   
#   echo "use_logging=1" >> /home/zerogame/.zerogame/zerogamerc
# else
#   
#   echo "use_logging=0" >> /home/zerogame/.zerogame/zerogamerc
# fi

cp ~/fonts/* /usr/share/fonts/
fc-cache -f

touch /home/zerogame/.zerogame/zerogamerc
echo "WAHCADETHEME=retrogame" > /home/zerogame/.zerogame/zerogamerc
echo "ZEROGAMEDEBUG=0" >> /home/zerogame/.zerogame/zerogamerc
#echo "c64install=$c64install" >> /home/zerogame/.zerogame/zerogamerc
echo "tg16install=$tg16install" >> /home/zerogame/.zerogame/zerogamerc
echo "segacdinstall=$segacdinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "ngpcinstall=$ngpcinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "ngpinstall=$ngpinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "mameinstall=$mameinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gginstall=$gginstall" >> /home/zerogame/.zerogame/zerogamerc
echo "geninstall=$geninstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gbainstall=$gbainstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gbcinstall=$gbcinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "gbinstall=$gbinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "nesinstall=$nesinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "snesinstall=$snesinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "wsinstall=$wsinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "wscinstall=$wscinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "fdsinstall=$fdsinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "lynxinstall=$lynxinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "smsinstall=$smsinstall" >> /home/zerogame/.zerogame/zerogamerc
echo "ZEROGAMEVERSION=50" >> /home/zerogame/.zerogame/zerogamerc
echo "GIZMODENABLE=1" >> /home/zerogame/.zerogame/zerogamerc
echo "CHECKZEROGAMEUPDATES=1" >> /home/zerogame/.zerogame/zerogamerc
echo "USEZEROGAMEMAMELISTING=0" >> /home/zerogame/.zerogame/zerogamerc
echo "ZEROGAMEDYNAMICRES=1" >> /home/zerogame/.zerogame/zerogamerc
chown zerogame:zerogame /home/zerogame/.zerogame/zerogamerc
chmod -R 600 /home/zerogame/.zerogame/zerogamerc

# Autologin Zerogame user.
cp ./configs/ydl/inittab /etc/inittab
cp ./configs/ydl/bash_profile /home/zerogame/.bash_profile
cp ./configs/ydl/xinitrc /home/zerogame/.xinitrc
mv /usr/share/rhgb/large-computer.png /usr/share/rhgb/oldlarge-computer.png
cp ./configs/ydl/large-computer.png /usr/share/rhgb/large-computer.png
chown zerogame /home/zerogame/.bash_profile
chown zerogame /home/zerogame/.xinitrc

cp -R /root/backgrounds/ /home/zerogame/.zerogame/
cp -R /root/configs/ /home/zerogame/.zerogame/
cp -R /root/docs/ /home/zerogame/.zerogame/
cp -R /root/fonts/ /home/zerogame/.zerogame/
cp -R /root/layouts/ /home/zerogame/.zerogame/
cp -R /root/packages/ /home/zerogame/.zerogame/
cp -R /root/patches/ /home/zerogame/.zerogame/
cp -R /root/sfx/ /home/zerogame/.zerogame/
cp -R /root/tools/ /home/zerogame/.zerogame/
cp -R /root/wrappers/ /home/zerogame/.zerogame/
chown -R zerogame:zerogame /home/zerogame/.zerogame/
chmod 755 /home/zerogame/.zerogame/tools/*
chmod 755 /home/zerogame/.zerogame/wrappers/*

if [ "$segacdinstall" == "1" ]; then
 read -p "Please be aware that since you installed SegaCD support, you will need to find a copy of the SegaCD BIOS file and place it at /home/zerogame/.xe/bios/megacd-u.bin for either Sega Genesis or SegaCD to work. Press Enter to continue."
 echo -e '\n'
fi


if [ "$fdsinstall" == "1" ]; then
 read -p "Please be aware that since you installed Famicom Disk System support, you will need to find a copy of the FDS BIOS file and place it at /home/zerogame/.mednafen/disksys.rom for it to work. Press Enter to continue."
 echo -e '\n'
fi

if [ "$lynxinstall" == "1" ]; then
 read -p "Please be aware that since you installed Atari Lynx support, you will need to find a copy of the Lynx BIOS file and place it at /home/zerogame/.mednafen/lynxboot.img for it to work. Press Enter to continue."
 echo -e '\n'
fi

while true; do
    read -n1 -p "Congratulations, your installation of zerogame is now complete and requires a reboot before use. Do you want to Reboot now? [y/n] " rebootans
    case $rebootans in
	[Yy]* )
          reboot
          break;;
        [Nn]* )
          break;;
        * ) echo -e "\nPlease answer yes or no.";;
    esac
done
echo -e '\n'

 
